==> netbox_storage-0.0.0.0.658.tar.gz: netbox_storage-0.0.0.0.658/netbox_storage/forms/linux_device.py <==
from django.forms import (
    CharField
)

from netbox.forms import (
    NetBoxModelBulkEditForm,
    NetBoxModelFilterSetForm,
    NetBoxModelImportForm,
    NetBoxModelForm,
)

from netbox_storage.models import LinuxDevice


class LinuxDeviceForm(NetBoxModelForm):
    device = CharField(
        label="Device Name",
        help_text="The mounted path of the volume e.g. /var/lib/docker",
    )

    class Meta:
        model = LinuxDevice

        fields = (
            "device",
            "type",
            "description",
        )

    #def save(self, *args, **kwargs):
    #    new_partition_count = Partition.objects.filter(drive_id=self.cleaned_data['drive'].id).count() + 1
    #    device_name_prefix = Drive.objects.get(pk=self.cleaned_data['drive'].id).device_name()
    #    device_name = device_name_prefix + str(new_partition_count)


     #   return linux_device
        """
        project_owner_pk = ContactRole.objects.get(name='Project Owner').pk
        ocp_project_type_pk = ContentType.objects.get(app_label='ocp_project_plugin', model='ocpproject').pk

        count_assignment = ContactAssignment.objects.filter(object_id=self.pk).count()
        if count_assignment == 0:
            ContactAssignment.objects.create(object_id=self.pk,
                                             contact_id=self.project_owner.pk,
                                             content_type_id=ocp_project_type_pk,
                                             role_id=project_owner_pk)

        """


class LinuxDeviceFilterForm(NetBoxModelFilterSetForm):

    model = LinuxDevice

    device = CharField(
        label="Device",
        help_text="The mounted path of the volume e.g. /var/lib/docker",
    )


class LinuxDeviceImportForm(NetBoxModelImportForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    class Meta:
        model = LinuxDevice

        fields = (
            "device",
            "type",
            "description",
        )


class LinuxDeviceBulkEditForm(NetBoxModelBulkEditForm):
    model = LinuxDevice

    device = CharField(
        required=False,
        label="Device",
    )
    type = CharField(
        required=False,
        label="Type",
    )
    description = CharField(max_length=255, required=False)

    fieldsets = (
        (
            None,
            ("device", "type", "description"),
        ),
    )
    nullable_fields = ["description"]

==> netbox_storage-0.0.0.0.797.tar.gz: netbox_storage-0.0.0.0.797/netbox_storage/forms/linux_device.py <==
from django.forms import (
    CharField, FloatField, HiddenInput
)

from netbox.forms import (
    NetBoxModelBulkEditForm,
    NetBoxModelFilterSetForm,
    NetBoxModelImportForm,
    NetBoxModelForm,
)

from netbox_storage.models import LinuxDevice


class LinuxDeviceForm(NetBoxModelForm):
    device = CharField(
        label="Device Name",
        help_text="The mounted path of the volume e.g. /var/lib/docker",
    )
    type = CharField(
        label="Device Type",
        help_text="The type of the device e.g. Disk, Partition, LVM",
        max_length=255,
    )
    size = FloatField(
        label="Size",
        help_text="The size of the device e.g. 200",
    )

    class Meta:
        model = LinuxDevice

        fields = (
            'content_type',
            'object_id',
            "device",
            "type",
            "size",
        )
        widgets = {
            'content_type': HiddenInput(),
            'object_id': HiddenInput(),
        }

"""
    def save(self, *args, **kwargs):
        object_pk = self.cleaned_data['parent_object'].pk

        self.instance.content_type_pk = ContentType.objects.get(app_label='netbox_storage', model='linuxdevice').pk
        self.instance.object_id = object_pk

        linux_device = super().save(*args, **kwargs)

        return linux_device
"""


class LinuxDeviceFilterForm(NetBoxModelFilterSetForm):

    model = LinuxDevice

    device = CharField(
        label="Device",
        help_text="The mounted path of the volume e.g. /var/lib/docker",
    )


class LinuxDeviceImportForm(NetBoxModelImportForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    class Meta:
        model = LinuxDevice

        fields = (
            "device",
            "type",
        )


class LinuxDeviceBulkEditForm(NetBoxModelBulkEditForm):
    model = LinuxDevice

    device = CharField(
        required=False,
        label="Device",
    )
    type = CharField(
        required=False,
        label="Type",
    )

    fieldsets = (
        (
            None,
            ("device", "type"),
        ),
    )
